%define ALD_Ver		2.0
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

Name:         libgcrypt20

License:      GPL LGPL
Summary:      Libgcrypt - The GNU Crypto Library
Version:      1.10.3
Release:      0

Requires:         libgpg-error >= 1.4

Source: libgcrypt-%{version}.tar.xz

#https://www.gnupg.org/ftp/gcrypt/libgcrypt/

%define DestDir		/crypt
# -----------------------------------------------------

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/%{name}

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
Libgcrypt - The GNU Crypto Library
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Conflicts:    libgcrypt-devel
Conflicts:    libgcrypt11-devel
Requires:     %{name} = %{version}
%description devel
These libraries are needed to compile C code.
#-------------------------------
%package info
Summary:      Info for %{org_name}
Conflicts:    libgcrypt-info
Conflicts:    libgcrypt11-info
%description info
Info for %{org_name}
#-------------------------------
%package %{_target_cpu}
Summary:      %{name} Cross-%{_target_cpu}
Buildarch:    noarch
autoreqprov:  0
%description %{_target_cpu}
%{name} Cross-%{_target_cpu}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n libgcrypt-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
export PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i586 -falign-functions=4 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -O2 -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -fno-asynchronous-unwind-tables -fno-stack-protector"

CFLAGS="$OPTFLAGS -std=gnu99"
CXXFLAGS="$OPTFLAGS"
LDFLAGS="-Wl,--gc-sections"

# should be all algorithms except SM3 and SM4
export DIGESTS='crc gostr3411-94 md4 md5 rmd160 sha1 sha256 sha512 sha3 tiger whirlpool stribog blake2'
export CIPHERS='arcfour blowfish cast5 des aes twofish serpent rfc2268 seed camellia idea salsa20 gost28147 chacha20'

%configure \
	--enable-shared \
	--disable-static \
	--disable-libtool-lock \
	--disable-sse41-support \
	--disable-avx-support \
	--disable-avx2-support \
	--disable-neon-support \
	--disable-O-flag-munging \
	--disable-jent-support \
	--enable-digests="$DIGESTS" \
	--enable-ciphers="$CIPHERS" \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
export  PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt
rm $RPM_BUILD_ROOT%{_libdir}/*.la
rm $RPM_BUILD_ROOT%{_infodir}/dir

cp AUTHORS LICENSES README $RPM_BUILD_ROOT%{docdir}
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING
ln -s /usr/share/doc/lgpl-2.1.txt $RPM_BUILD_ROOT%{docdir}/COPYING.LIB

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} -DelLocCrossDir=%{_bindir}
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
#/etc/gcrypt/random.conf.default
%{_libdir}/libgcrypt.so.*
%{docdir}

%files devel
%{_bindir}/dumpsexp
%{_bindir}/hmac256
%{_bindir}/mpicalc
%{_bindir}/libgcrypt-config
%{_includedir}
%{_libdir}/pkgconfig/libgcrypt.pc
%{_libdir}/libgcrypt.so
%{_datadir}/aclocal
%{_mandir}

%files info
%{_infodir}
